import { Router } from 'express';
import jwt from 'jsonwebtoken';
import User, { IUser } from '../models/User.js';
const router = Router();

router.post('/register', async (req, res) => {
  try {
    const { email, password, name } = req.body as IUser;
    const user = await User.create({ email, password, name });
    const token = jwt.sign({ id: user.id, email }, process.env.JWT_SECRET!);
    res.json({ token, user: { id: user.id, email, name } });
  } catch (err: any) {
    res.status(400).json({ message: 'Registrazione fallita', error: err.message });
  }
});

router.post('/login', async (req, res) => {
  const { email, password } = req.body as IUser;
  const user = await User.findOne({ email });

  if (!user || !(await user.comparePassword(password))) {
    res.status(401).json({ message: 'Credenziali non valide' });
    return;               // ← esce senza value → tipo void
  }

  const token = jwt.sign({ id: user.id, email }, process.env.JWT_SECRET!);
  res.json({ token, user: { id: user.id, email, name: user.name } });
});
export default router;
