import { Router } from 'express';
import Tag from '../models/Tag.js';
import Item from '../models/Item.js';
import auth from '../middleware/auth.js';

const router = Router();

/* ──────────── GET: tutti i tag ──────────── */
router.get('/', async (_req, res) => {
  res.json(await Tag.find());
});

/* ──────────── POST: crea tag (protetto) ──────────── */
router.post('/', auth, async (req, res) => {
  const { name, color } = req.body as { name: string; color: string };
  const tag = await Tag.create({ name, color });
  res.status(201).json(tag);
});

/* ──────────── DELETE: elimina tag (protetto) ──────────── */
router.delete('/:id', auth, async (req, res) => {
  const { id } = req.params;

  // opzionale: blocca l’eliminazione se il tag è ancora assegnato a qualche item
  const inUse = await Item.exists({ tags: id });
  if (inUse) {
    res.status(409).json({ message: 'Tag in uso: rimuovilo dagli item prima di cancellarlo' });
    return;
  }

  const deleted = await Tag.findByIdAndDelete(id);
  if (!deleted) {
    res.status(404).json({ message: 'Tag non trovato' });
    return;
  }

  res.status(204).end();
});

export default router;
